/******************************************************************************/
// Code to generate simple levels and changes graphs (Figures 1 and 2)
/******************************************************************************/

/******************************************************************************/
// Load dataset
/******************************************************************************/
use "$filepath\data\resultsdata.dta"


/******************************************************************************/
// Levels graphs (Figure 1 in paper)
/******************************************************************************/
foreach ind in $indlist{
	// Upper and lower bounds of 90% confidence interval
	gen `ind'_upper=`ind'e23+1.64*`ind's23
	gen `ind'_lower=`ind'e23-1.64*`ind's23
	// Recalculate percentile rank breaking ties, just to avoid "gaps" in graph
	egen `ind'_urank=rank(`ind'e23), unique
	gen `ind'_labels=countryname if `ind'_urank==20 | `ind'_urank==20 | `ind'_urank==40 | `ind'_urank==60 | `ind'_urank==80 | `ind'_urank==100 | `ind'_urank==120 | `ind'_urank==140 | `ind'_urank==160 | `ind'_urank==180 | `ind'_urank==200 
	su `ind'_urank
	replace `ind'_urank=`ind'_urank/r(max)*100
	// Levels graph
	twoway (rspike `ind'_upper `ind'_lower `ind'_urank, lcolor(gray)) /// 
			(scatter `ind'e23 `ind'_urank, mlabel(`ind'_labels) mlabangle(vertical) mlabposition(12) mlabcolor(black*200) mlabsize(small) mlabgap(20pt)) ///
			, legend(off) xtitle("Percentile Rank") ytitle("Estimate of Governance") title("`ind'") name("levelfig_`ind'", replace)
}
// Six panel version of graph (hard to read, not used in paper)
graph combine levelfig_va levelfig_pv levelfig_ge levelfig_rq levelfig_rl levelfig_cc, ///
	rows(3) cols(2) ysize(8) xsize(6) ///
	title("Estimates of Governance, 2023") name("levelfig_6panel", replace)
// Two-panel version of graph (more legible, used in paper)
graph combine levelfig_ge levelfig_cc, ///
	rows(2) cols(1) ysize(8) xsize(6) ///
	title("Estimates of Governance, 2023") name("levelfig_2panel", replace) 
graph save "$filepath\outputs\figure1", replace	

/******************************************************************************/
// Graphs showing changes over time (Figure 2 in paper)
/******************************************************************************/
// select first and last year to compare
local firstyr 96
local lastyr 23
foreach ind in $indlist{
	gen `ind'`firstyr'_lower=`ind'e`firstyr'-1.64*`ind's`firstyr'
	gen `ind'`firstyr'_upper=`ind'e`firstyr'+1.64*`ind's`firstyr'
	gen `ind'`lastyr'_lower=`ind'e`lastyr'-1.64*`ind's`lastyr'
	gen `ind'`lastyr'_upper=`ind'e`lastyr'+1.64*`ind's`lastyr'
	gen `ind'_labsmpl=countryname if `ind'`lastyr'_lower>`ind'`firstyr'_upper | `ind'`lastyr'_upper<`ind'`firstyr'_lower
	twoway (scatter `ind'e`lastyr' `ind'e`firstyr') /// 
			(scatter `ind'e`lastyr' `ind'e`firstyr' if `ind'_labsmpl~="", mlabel(`ind'_labsmpl) mlabposition(2) mlabcolor(black)) ///
			(rspike `ind'`lastyr'_upper `ind'`lastyr'_lower `ind'e`firstyr' if `ind'_labsmpl~="", lcolor(gray)) ///
			(pcspike `ind'e`lastyr' `ind'`firstyr'_upper `ind'e`lastyr' `ind'`firstyr'_lower if `ind'_labsmpl~="", lcolor(gray)) ///
			(lfit `ind'e`firstyr' `ind'e`firstyr' ) ///
			, aspect(1) legend(off) xtitle("1996") ytitle("2023") title("`ind'") name("changefig_`ind'", replace)
	}
// Six panel version of graph (hard to read, not used in paper)
graph combine changefig_va changefig_pv changefig_ge changefig_rq changefig_rl changefig_cc, ///
	rows(3) cols(2) ysize(8) xsize(6) ///
	title("Changes in Governance 1996-2023") name("changefig_6panel", replace)
// Two-panel version of graph (more legible, used in paper as Figure 2)
graph combine changefig_va changefig_rl, ///
	rows(2) cols(1) ysize(8) xsize(6) ///
	title("Changes in Governance 1996-2023") name("changefig_2panel", replace)
graph save "$filepath\outputs\figure2", replace	
