/******************************************************************************/
// Code to document prevalence of different types of data sources
/******************************************************************************/

/******************************************************************************/
// Count of countries covered in most recent year (first column in Table 1)
// Note list of sources below flags last year available for each source
// Exports first column of Table 1 (number of countries covered) as row vector
// into table1a.xlsx, in same order as entries in Table 1
/******************************************************************************/
clear
use "$filepath\data\sourcedata.dta"
foreach src in adb23 afr23 asd23 bps15 bti23 ccr13 ebr16 eiu23 eqi23 frh23 gcb22 gcs23 gii23 gwp23 her23 hrm23 hum23 ifd23 ijt23 ipd19 irp23 lbo23 msi23 obi23 pia23 prc23 prs23 rsf23 tpr23 vab23 vdm23 wbs23 wcy23 wjp23 wmo23{
	egen xx=rownonmiss(`src'*)
	replace xx=1 if xx>0
	egen `src'_nctrys=sum(xx)
	drop xx
}
export excel *_nctrys using "$filepath\outputs\table1a.xlsx" if code=="USA", firstrow(var) replace

/******************************************************************************/
// Document use of data sources over time in WGI (remaining columns of Table 1)
// Exports matrix of dummy variables corresponding to the "x" markers in Table 1
/******************************************************************************/
clear
use "$filepath\data\wgidataset_with_sourcedata.dta"
foreach src in $sourcelist{
	egen xx=count(`src'), by(year)
	gen `src'_used=0
	replace `src'_used=1 if xx>0
	drop xx
}
export excel year *_used using "$filepath\outputs\table1b.xlsx" if code=="USA" & indicator=="va", firstrow(var) replace

/******************************************************************************/
// Define groups of data sources by type of data source
/******************************************************************************/
global surveysourcelist "afr bps eqi gcb gcs gwp lbo prc vab wbs wcy"
global govsourcelist "adb asd ebr hum ifd ipd pia tpr"
global cbipsourcelist "eiu prs wmo ijt"
global ngosourcelist "bti ccr frh gii her hrm irp msi obi rsf vdm wjp"
global sourcetypes "survey gov cbip ngo"

/******************************************************************************/
// Count up country-indicator-year data points of each type (Table 2 in paper)
/******************************************************************************/
foreach type in $sourcetypes{
	gen `type'=0
	foreach src in $`type'sourcelist{
	replace `type'=`type'+1 if `src'~=.
	}	
}

tabstat $sourcetypes, by(indicator) stats(sum)